@@ -1,20 +1,19 @@
-import io
 import os
 import shutil
 import tempfile
 from contextlib import ExitStack
 from tarfile import TarFile, TarInfo
-from typing import IO, Optional, Union
+from typing import IO, List, Optional, Union
 from zipfile import ZipFile, ZipInfo
 
 
 class File:
     parent_file: Optional["File"] = None
 
-    def open(self) -> io.BufferedReader:
+    def open(self) -> IO[bytes]:
         raise NotImplementedError("...")
 
-    def read(self):
+    def read(self) -> bytes:
         with self.open() as f:
             return f.read()
 
@@ -35,13 +34,15 @@ class FileOnDisk(File):
     path: str
     dir_entry: Optional[os.DirEntry]
 
-    def __init__(self, name, path, dir_entry=None):
+    def __init__(
+        self, name: str, path: str, dir_entry: Optional[os.DirEntry] = None
+    ) -> None:
         self._name = name
         self.path = path
         self.dir_entry = dir_entry
 
-    def open(self):
-        return open(self.path, "rb")
+    def open(self) -> IO[bytes]:
+        return open(self.path, "rb")  # noqa: SIM115
 
     @property
     def name(self) -> str:
@@ -51,18 +52,18 @@ class FileOnDisk(File):
 class FileInContainer(File):
     _concrete_path: Optional[str] = None
 
-    def open_concrete(self, delete=True):
+    def open_concrete(self, delete: bool = True) -> IO[bytes]:
         if self._concrete_path and os.path.isfile(self._concrete_path):
-            return open(self._concrete_path)
+            return open(self._concrete_path, "rb")  # noqa: SIM115
         tf = tempfile.NamedTemporaryFile(suffix=self.extension, delete=delete)
         self.extract(tf)
         tf.seek(0)
         self._concrete_path = tf.name
         return tf
 
-    def extract(self, destination: Union[str, IO]):
+    def extract(self, destination: Union[str, IO]) -> None:
         if isinstance(destination, str):
-            destination = open(destination, "wb")
+            destination = open(destination, "wb")  # noqa: SIM115
             should_close = True
         else:
             should_close = False
@@ -72,22 +73,25 @@ class FileInContainer(File):
             if should_close:
                 destination.close()
 
-    def _do_extract(self, destination: IO):
+    def _do_extract(self, destination: IO) -> None:
         # if a file has a better idea how to write itself into an IO, this is the place
         with self.open() as f:
             shutil.copyfileobj(f, destination)
 
 
 class FileInZip(FileInContainer):
+    parent_file: FileOnDisk
     zipfile: ZipFile
     zipinfo: ZipInfo
 
-    def __init__(self, parent_file, zipfile, zipinfo):
+    def __init__(
+        self, parent_file: FileOnDisk, zipfile: ZipFile, zipinfo: ZipInfo
+    ) -> None:
         self.parent_file = parent_file
         self.zipfile = zipfile
         self.zipinfo = zipinfo
 
-    def open(self):
+    def open(self) -> IO[bytes]:
         return self.zipfile.open(self.zipinfo, "r")
 
     @property
@@ -104,16 +108,22 @@ class FileInZip(FileInContainer):
 
 
 class FileInTar(FileInContainer):
+    parent_file: FileOnDisk
     tarfile: TarFile
     tarinfo: TarInfo
 
-    def __init__(self, parent_file, tarfile, tarinfo):
+    def __init__(
+        self, parent_file: FileOnDisk, tarfile: TarFile, tarinfo: TarInfo
+    ) -> None:
         self.parent_file = parent_file
         self.tarfile = tarfile
         self.tarinfo = tarinfo
 
-    def open(self):
-        return self.tarfile.extractfile(self.tarinfo)
+    def open(self) -> IO[bytes]:
+        fp = self.tarfile.extractfile(self.tarinfo)
+        if not fp:
+            raise ValueError(f"extractfile() returned None for {self.tarinfo}")
+        return fp
 
     @property
     def name(self) -> str:
@@ -121,7 +131,8 @@ class FileInTar(FileInContainer):
 
 
 def find_files_in_zip(vr: "VFS", df: FileOnDisk) -> None:
-    df.zipfile = zf = ZipFile(df.path)
+    zf = ZipFile(df.path)
+    df.zipfile = zf  # type: ignore
     vr.exit_stack.callback(zf.close)
     vr.files.extend(
         [
@@ -132,7 +143,8 @@ def find_files_in_zip(vr: "VFS", df: FileOnDisk) -> None:
 
 
 def find_files_in_tar(vr: "VFS", df: FileOnDisk) -> None:
-    df.tarfile = tf = TarFile.open(df.path)
+    tf = TarFile.open(df.path)
+    df.tarfile = tf  # type: ignore
     vr.exit_stack.callback(tf.close)
     vr.files.extend(
         [
@@ -144,14 +156,16 @@ def find_files_in_tar(vr: "VFS", df: FileOnDisk) -> None:
 
 
 class VFS:
-    def __init__(self):
+    files: List[File]
+
+    def __init__(self) -> None:
         self.files = []
         self.exit_stack = ExitStack()
 
-    def __enter__(self):
+    def __enter__(self) -> "VFS":
         return self
 
-    def __exit__(self, *exc_details):
+    def __exit__(self, *exc_details) -> None:
         self.exit_stack.__exit__(*exc_details)
 
 
@@ -160,8 +174,8 @@ def add_disk_file(
     name: str,
     path: str,
     dir_entry: Optional[os.DirEntry] = None,
-    process_archives=False,
-):
+    process_archives: bool = False,
+) -> None:
     disk_file = FileOnDisk(name=name, path=path, dir_entry=dir_entry)
     if process_archives:
         extension = disk_file.extension.lower()
@@ -174,7 +188,7 @@ def add_disk_file(
     vfs.files.append(disk_file)
 
 
-def find_files(vfs: VFS, root: str, *, process_archives: bool):
+def find_files(vfs: VFS, root: str, *, process_archives: bool) -> None:
     dent: os.DirEntry
 
     def _walk(path):
